Touches

Struct Touches 

pub struct Touches { /* private fields */ }
A collection of Touches.

Usage

It is used to create a bevy resource that stores the data of the touches on a touchscreen and can be accessed inside of a system.

Updating

The resource is updated inside of the touch_screen_input_system.

Implementations

Source

impl Touches

pub fn iter(&self) -> impl Iterator<Item = &Touch> + '_

An iterator visiting every pressed Touch input in arbitrary order.

pub fn get_pressed(&self, id: u64) -> Option<&Touch>

Returns the Touch input corresponding to the id if it is being pressed.

pub fn any_just_pressed(&self) -> bool

Checks if any touch input was just pressed.

pub fn release(&mut self, id: u64)

Register a release for a given touch input.

pub fn release_all(&mut self)

Registers a release for all currently pressed touch inputs.

pub fn just_pressed(&self, id: u64) -> bool

Returns true if the input corresponding to the id has just been pressed.

pub fn clear_just_pressed(&mut self, id: u64) -> bool

Clears the just_pressed state of the touch input and returns true if the touch input has just been pressed.

Future calls to Touches::just_pressed for the given touch input will return false until a new press event occurs.

pub fn iter_just_pressed(&self) -> impl Iterator<Item = &Touch>

An iterator visiting every just pressed Touch input in arbitrary order.

pub fn get_released(&self, id: u64) -> Option<&Touch>

Returns the Touch input corresponding to the id if it has just been released.

pub fn any_just_released(&self) -> bool

Checks if any touch input was just released.

pub fn just_released(&self, id: u64) -> bool

Returns true if the input corresponding to the id has just been released.

pub fn clear_just_released(&mut self, id: u64) -> bool

Clears the just_released state of the touch input and returns true if the touch input has just been released.

Future calls to Touches::just_released for the given touch input will return false until a new release event occurs.

pub fn iter_just_released(&self) -> impl Iterator<Item = &Touch>

An iterator visiting every just released Touch input in arbitrary order.

pub fn any_just_canceled(&self) -> bool

Checks if any touch input was just canceled.

pub fn just_canceled(&self, id: u64) -> bool

Returns true if the input corresponding to the id has just been canceled.

pub fn clear_just_canceled(&mut self, id: u64) -> bool

Clears the just_canceled state of the touch input and returns true if the touch input has just been canceled.

Future calls to Touches::just_canceled for the given touch input will return false until a new cancel event occurs.

pub fn iter_just_canceled(&self) -> impl Iterator<Item = &Touch>

An iterator visiting every just canceled Touch input in arbitrary order.

pub fn first_pressed_position(&self) -> Option<Vec2>

Retrieves the position of the first currently pressed touch, if any

pub fn clear(&mut self)

Clears just_pressed, just_released, and just_canceled data for every touch input.

See also Touches::reset_all for a full reset.

pub fn reset_all(&mut self)

Clears pressed, just_pressed, just_released, and just_canceled data for every touch input.

See also Touches::clear for clearing only touches that have just been pressed, released or canceled.